/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Calendar **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:42+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Dutch (Netherlands) (http://www.transifex.com/tine20/tine20/language/nl_NL/)\nLanguage: nl_NL\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "{0}, the {1}. of {2}"
: "{0}, de {1}. van {2}"

, "Recurrances"
: "Herhalingen"

, "No recurring rule defined"
: "Geen terugkerende regel gedefinieerd"

, "Details"
: "Details"

, "None"
: "Geen"

, "Daily"
: "Dagelijks"

, "Weekly"
: "Wekelijks"

, "Monthly"
: "Maandelijks"

, "Yearly"
: "Jaarlijks"

, "Exceptions of reccuring events can't have recurrences themselves."
: "Uitzonderingen van herhalende gebeurtenissen kunnen niet zelf herhalend zijn."

, "at"
: "op"

, "never"
: "Nooit"

, "after {0} occurrences"
: "na {0} herhalingen"

, "Except"
: ""

, "during events in the calendars"
: ""

, "End"
: "Einde"

, "Until has to be after event start"
: "Einde moet na de start van het evenement vallen"

, "The event is longer than the recurring interval"
: "De gebeurtenis is langer dan het herhalende interval"

, "Every {0}. Day"
: "Elke {0} dag"

, "Every {0}. Week at"
: "Elke {0} week op"

, "Every {0}. Month"
: "Elke {0} maand"

, "at the"
: "op de"

, "first"
: "eerste"

, "second"
: "tweede"

, "third"
: "derde"

, "fourth"
: "vierde"

, "last"
: "laatste"

, "Every {0}. Year"
: "Elke {0} jaar"

, "of"
: " "

, "Summary"
: "Samenvatting"

, "Organizer"
: "Organisator"

, "Description"
: "Beschrijving"

, "Location"
: "Locatie"

, "Start Time"
: "Begin tijd"

, "End Time"
: "Eind tijd"

, "Attendee"
: "Genodigde"

, "whole day"
: "Gehele dag"

, "Week {0} :"
: "Week {0} :"

, "Poll, Polls"
: [
  ""
 ,""

]
, "Options"
: ""

, "Alternative Dates"
: ""

, "Set as definite event"
: ""

, "Create Poll for this Event"
: ""

, "Name for poll"
: ""

, "Create scheduling suggestions and pick the best alternative based on user feedback."
: ""

, "Share the link below to poll for attendee status feedback."
: ""

, "Public URL"
: ""

, "Protect poll with a password"
: ""

, "Only invited attendee can reply"
: ""

, "Start Date"
: ""

, "Info"
: ""

, "loading alternative dates"
: ""

, "Select one Event Only"
: ""

, "You need to select exactly one event as the definite event."
: ""

, "Setting definite event"
: ""

, "New Event"
: "Nieuw evenement"

, "Calendar, Calendars"
: [
  "Agenda"
 ,"Agenda's"

]
, "Event not found"
: ""

, "The Event was deleted in the meantime or you don't have access rights to it."
: ""

, "Switch to public poll"
: ""

, "Welcome {name}"
: ""

, "This is a closed poll. No Attendee can be added."
: ""

, "This poll is closed already"
: ""

, "I am not {name}"
: ""

, "Login"
: ""

, "{headerDate, date, full} {headerDate, time, short}"
: ""

, "Cancel"
: ""

, "Save"
: ""

, "By using this service you agree to our terms and conditions"
: ""

, "Use your personal link please."
: ""

, "We have sent it to your E-Mail account again."
: ""

, "If you did not receive the link, please contact the organiser."
: ""

, "Password"
: ""

, "Submit"
: ""

, "Wrong password!"
: ""

, "Please log in"
: ""

, "User name"
: ""

, "Calendar of {name}"
: ""

, "An unexpected error occurred."
: ""

, "Add attendee"
: "Voeg genodigde toe"

, "Sort Attendee"
: "Sorteer genodigde"

, "Check to filter for this attendee"
: "Vink aan om te filteren op deze attendee"

, "Unavailable"
: ""

, "Loading events, please wait..."
: "Laden van de evenementen. Moment..."

, "Cut event"
: "Knip evenement"

, "Copy Event to clipboard"
: "Kopieer evenement naar clipboard"

, "Stop cut / copy & paste"
: "Stop knip/kopie & plakken"

, "Print Page"
: "Druk pagina af"

, "Loose-Leaf"
: ""

, "Sheet"
: "Staat"

, "Grid"
: "Rooster"

, "Timeline"
: ""

, "Day"
: "Dag"

, "Week"
: "Week"

, "Month"
: "Maand"

, "Year"
: ""

, "Custom Selection"
: ""

, "Import Events"
: "Importeer evenement"

, "Paste event \"{0}\""
: "Plak evenement \"{0}\""

, "Set my response"
: "Zet mijn antwoord"

, "Copy {0}"
: "Kopieer {0}"

, "Set event status"
: ""

, "Updating event in the past"
: "Aanpassen van evenement in het verleden"

, "Update this event"
: "Pas dit evenement aan"

, "Do not update this event"
: "Pas dit evenement niet aan"

, "Creating event in the past"
: "Aanmaken van evenement in het verleden"

, "Create this event"
: "Maak dit evenement aan"

, "Do not create this event"
: "Dit evenement niet creëren"

, "Update this event only"
: "Update alleen dit evenement"

, "Update this and all future events"
: "Pas dit en alle toekomstige evenementen aan "

, "Update whole series"
: "Update de gehele serie"

, "Update nothing"
: "Update niks"

, "Update Event"
: "Update evenement"

, "Please Change Selection"
: "Pas uw selectie aan"

, "Your selection contains recurring events. Recuring events must be deleted seperatly!"
: "Uw selectie bevat terugkerende evenementen. Terugkerende evenementen moeten separaat verwijderd worden!"

, "Delete Event"
: "Verwijder evenement"

, "Delete this event only"
: "Verwijder alleen dit evenement"

, "Delete this and all future events"
: "Verwijder dit en alle toekomstige evenementen"

, "Delete whole series"
: "Verwijder gehele serie"

, "Delete nothing"
: "Verwijder niks"

, "Do you really want to delete this event?, Do you really want to delete the {0} selected events?"
: [
  "Weet u zeker dat dit evenement verwijderd moet worden?"
 ,"Weet u zeker dat de {0} geselecteerde evenementen verwijderd moeten worden?"

]
, "Could not Print"
: "Kan niet printen"

, "Sorry, your current view does not support printing."
: "De huidige view ondersteunt geen printen"

, "Scheduling Conflict"
: "Schedule conflict"

, "The following attendee are busy at the requested time:"
: "De volgende genodigde zijn druk op het voorgestelde tijdstip:"

, "Ignore Conflict"
: "Negeer conflict"

, "Edit Event"
: "Bewerk evenement"

, "Cancel this action"
: "Breek deze actie af"

, "Update Status for all Attendee?"
: ""

, "You are about to change the status of the event itself and not just your own status. Do you really want to change the event status for all attendee?"
: ""

, "Manage Resources"
: "Beheer bronnen"

, "GENDER_Attendee"
: ""

, "Select Attendee"
: "Selecteer genodigde"

, "Attachments"
: ""

, "Private"
: "Prive"

, "Tags"
: "Tags"

, "Blocking"
: "Blokkerend"

, "Tentative"
: "Onder voorbehoud"

, "Import Definition Success!"
: "Import van definitie gelukt!"

, "The Ical Import definition has been created successfully! Please wait some minutes to get the events synced by the cronjob."
: "De geimporteerde iCal definitie is succesvol! Wacht een paar minuten tot de gebeurtenissen worden gesynchroniseerd door de cronjob."

, "Choose Import File"
: "Kies import bestand"

, "Please choose the file that contains the records you want to add to Tine 2.0"
: "Kies het bestand dat de Afspraken bevat die u aan Tine 2.0 wilt toevoegen."

, "Select file containing your {0}"
: "Selecteer het bestand met uw {0}"

, "once"
: "eenmalig"

, "hourly"
: "urelijks"

, "daily"
: "dagelijks"

, "weekly"
: "wekelijks"

, "Choose Remote Location"
: "Kies externe locatie"

, "Please choose a remote location you want to add to Tine 2.0"
: "Kies een externe locatie die u aan Tine 2.0 wilt toevoegen"

, "Username"
: ""

, "Refresh time"
: "Ververstijd"

, "General Settings"
: "Algemene instellingen"

, "Calendar name (you need permissions to add events)"
: ""

, "What should the file you upload look like?"
: "Hoe moet het bestand dat u upload eruit zien?"

, "Tine 2.0 does not understand all kind of files you might want to upload. You will have to manually adjust your file so Tine 2.0 can handle it."
: "Tine 2.0 snapt niet alle bestanden die u upload. U moet handmatig de bestanden aanpassen, zodat Tine 2.0 ze kan verwerken."

, "Following you find a list of all supported import formats and a sample file, how Tine 2.0 expects your file to look like."
: ""

, "Please select the import format of the file you want to upload"
: ""

, "Download example file"
: "Download voorbeeld bestand"

, "Remote / ICS"
: "Extern / ICS"

, "Remote / CalDAV (BETA)"
: "Extern / Caldav (BETA)"

, "Upload"
: "Upload"

, "Choose File and Format"
: "Kies bestand en formaat"

, "Select type of source"
: "Selecteer het type van de bron"

, "Please select the type of source you want to add to Tine 2.0"
: "Selecteer het type van de bron die u aan Tine 2.0 wilt toevoegen"

, "Importing {0}"
: "importeren {0}"

, "Back"
: ""

, "Next"
: ""

, "Ok"
: ""

, "Free Time Search"
: ""

, "Searching for Free Time..."
: ""

, "No Free Time found"
: ""

, "No free timeslot could be found Until {0}. Do you want to continue?"
: ""

, "Continue"
: ""

, "Give up"
: ""

, "Free Time Search Options"
: ""

, "private classification"
: "privé klassificatie"

, "recurring event"
: "Terugkerend evenement"

, "recurring event exception"
: "uitzondering op terugkerend evenement"

, "has alarm"
: "heeft alarm"

, "has attachments"
: "heeft bijlagen"

, "is part of an open poll"
: ""

, "Mini Calendar"
: "Kleine agenda"

, "WK"
: "WK"

, "{0} more..."
: "{0} meer..."

, "Resource Grant, Resource Grants"
: [
  ""
 ,""

]
, "Invite Resource"
: ""

, "The grant to invite the resource to an event"
: ""

, "Read Resource"
: ""

, "The grant to read the resource itself"
: ""

, "Edit Resource"
: ""

, "The grant to edit the resource itself"
: ""

, "Export Resource"
: ""

, "The grant to export the resource itself"
: ""

, "Sync Resource"
: ""

, "The grant to synchronise the resource itself"
: ""

, "Resource Admin"
: ""

, "The grant to administrate the resource itself"
: ""

, "Add Events"
: ""

, "The grant to directly add events into this resource calendar"
: ""

, "Read Events"
: ""

, "The grant to read events from this resource calendar"
: ""

, "Export Events"
: "Exporteer evenement"

, "The grant to export events from this resource calendar"
: ""

, "Sync Events"
: ""

, "The grant to synchronise events from this resource calendar. Need Read Events Grant"
: ""

, "Events Free Busy"
: ""

, "The grant to get free/busy information of events from this resource calendar"
: ""

, "Edit Events"
: ""

, "The grant to respond to event invitations of this resource and to edit events directly saved in this resource calendar"
: ""

, "Delete Events"
: ""

, "The grant to delete events directly stored in this resource calendar"
: ""

, "Free Busy"
: ""

, "The grant to get free/busy information of events in this calendar"
: ""

, "The grant to access events marked as private in this calendar"
: ""

, "Rrule"
: ""

, "Please choose the Event to add the contacts to"
: "Selecteer het evenement waaraan de contacten toegevoegd moeten worden"

, "Role"
: "Functie"

, "Select Role"
: "Selecteer functie"

, "Status"
: "Status"

, "Select Status"
: "Selecteer status"

, "Adding {0} Attendee to event"
: "Toevoegen {0} deelnemer aan event"

, "no events found"
: "Geen evenementen gevonden"

, "Searching..."
: "Zoeken..."

, "Search Event"
: "Zoek evenement"

, "Event, Events"
: [
  "Evenement"
 ,"Evenementen"

]
, "Additional Tags ..."
: ""

, "non-blocking"
: "Niet-blokkerend"

, "Displayed in"
: "Weergegeven in"

, "No Information"
: "Geen informatie"

, "Event Location"
: ""

, "From"
: ""

, "until"
: ""

, "Events"
: "Evenementen"

, "Calendars"
: "Agenda's"

, "Quick Search"
: "Snel zoeken"

, "GENDER_Calendar"
: ""

, "Attendee Status"
: "Status genodigde"

, "GENDER_Attendee Status"
: ""

, "Attendee Role"
: "Taak genodigde"

, "GENDER_Attendee Role"
: ""

, "GENDER_Status"
: ""

, "GENDER_Blocking"
: ""

, "Classification"
: "Klassificatie"

, "GENDER_Classification"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Unknown date"
: "Onbekende datum"

, "{0} {1} o'clock"
: "{0} {1} uur"

, "Event (as attendee)"
: "Evenementen (als genodigde)"

, "Event (as organizer)"
: "Evenementen (als organisator)"

, "Event attendee"
: "Genodigde voor evenement"

, "Attender, Attendee"
: [
  "Genodigde"
 ,"Genodigden"

]
, "Resource, Resources"
: [
  "Bron"
 ,"Bronnen"

]
, "Resources"
: "Bronnen"

, "Anyone"
: ""

, "Name"
: "Naam"

, "Calendar Hierarchy/Name"
: ""

, "Email"
: "E-mail"

, "Maximum number of attendee"
: ""

, "Type"
: "Type"

, "Default attendee status"
: ""

, "Busy Type"
: ""

, "Event finder options"
: ""

, "Click here to invite another attender..."
: "Klik hier om nog een genodigde toe te voegen..."

, "User"
: "Gebruiker"

, "Group"
: "Groep"

, "Member of group"
: "Groepslid"

, "This is the calendar where the attender has saved this event in"
: "Dit is de kalender waar de genodigde het evenement heeft opgeslagen"

, "Click icon to change"
: "Klik op het icoon om aan te passen"

, "Availability of Attendee"
: ""

, "Whole Group or each Member of Group"
: ""

, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
: ""

, "Member of Group"
: ""

, "Loading Groupmembers..."
: ""

, "Remove Attender"
: "Verwijder genodigde"

, "Compose email"
: "Maak een email"

, "Poll URL: {0}"
: ""

, "View Resource"
: ""

, "(as a group member)"
: "(als een groepslid)"

, "External Attendee"
: "Externe genodigde "

, "Originally"
: "Origineel"

, "Checking Calendar Data..."
: "Controleren van kalender data..."

, "Reply to Recurring Event"
: "Antwoorden op terugkerend evenement"

, "You are responding to an recurring event. What would you like to do?"
: "U beantwoordt een terugkerend evenement. Wat wilt u doen?"

, "Respond to whole series"
: "Beantwoord de gehele serie"

, "Do not respond"
: "Niet antwoorden"

, "The event of this message does not exist"
: "Het evenement van dit bericht bestaat niet"

, "The sender is not authorised to update the event"
: "De afzender is niet geautoriseerd om het evenement aan te passen"

, "This message is already processed"
: "Dit bericht is al verwerkt"

, "You are not an attendee of this event"
: "Je bent geen genodigde voor dit evenement"

, "This event has been deleted by the organizer"
: ""

, "This event has been canceled."
: ""

, "Unsupported message"
: "Niet ondersteund bericht"

, "This is an event invitation for someone else."
: "Dit is een evenementen uitnodiging voor iemand anders"

, "You have already replied to this event invitation."
: "U heeft deze uitnodiging al beantwoord."

, "The event got rescheduled. Set your response to:"
: ""

, "You received an event invitation. Set your response to:"
: "U heeft een uitnodiging ontvangen. Zet het antwoord op:"

, "An invited attendee responded to the invitation."
: "Een genodigde beantwoordde de uitnodiging."

, "Unsupported method"
: "Niet ondersteunde methode"

, "Suppress notification"
: ""

, "Color"
: ""

, "Enter description..."
: "Voer omschrijving in..."

, "Grants"
: "Rechten"

, "This event is originally stored in a calendar you don't have access to."
: "Dit evenement is geplaatst in een agenda waar je geen toegang tot hebt."

, "This event is originally stored in {0}"
: "Dit evenement is geplaatst in {0}"

, "This event is additionally displayed in your personal calendar {0}"
: "Dit evenement wordt bovendien weergegeven in uw persoonlijke kalender {0}"

, "Colors"
: ""

, "Side bar color"
: ""

, "Color by Calendar"
: ""

, "Color by Attendee Calendar"
: ""

, "Color by Tags"
: ""

, "Color by Attendee Role"
: ""

, "Colors by response"
: ""

, "Colors by tags"
: ""

, "Colors by attendee"
: ""

, "Colors by resource"
: ""

, "View"
: "Bekijk"

, "Saved in"
: "Opgeslagen in"

, "Enter description"
: "Voer omschrijving in"

, "Notifications are disabled"
: ""

, "Notifications are enabled"
: ""

, "Print Event"
: ""

, "Send Notification?"
: ""

, "Changes to this event might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
: ""

, "End date is not valid"
: "Eind datum is niet mogelijk"

, "End date must be after start date"
: "Eind datum moet na begin datum vallen"

, "End time is not allowed to be after the configured time."
: "Eindtijd mag niet na de geconfigureerde tijd zijn."

, "Start date is not valid"
: "Begin datum is niet mogelijk"

, "Start date is not allowed to be before the configured time."
: "Startdatum mag niet voor de geconfigureerde tijd zijn."

, "The summary must not be longer than 255 characters."
: "De samenvatting mag niet langer dan 255 tekens"

, "The summary must have at least 1 character."
: "De samenvatting moet minimaal uit 1 teken bestaan."

, "Summary too Long"
: "Samenvatting te lang"

, "Summary too Short"
: "Samenvatting te kort"

, "Set This Date as Definite Event?"
: ""

, "Do you want to close the poll and remove all other alternatives?"
: ""

, "Attendee/Resources"
: ""

, "Additional Attendees ..."
: ""

, "Default Status"
: ""

, "No Access"
: ""

, "All my events"
: "Al mijn evenementen"

, "Position on the left time axis, day and week view should start with"
: ""

, "Position on the left time axis, day and week view should end with"
: ""

, "Default Start Time"
: "Standaard start tijd"

, "Scroll position on the left time axis, day and week view should start with"
: ""

, "Visible Time"
: ""

, "Time to be displayed at once"
: ""

, "Default Calendar"
: "Standaard agenda"

, "The default calendar for invitations and new events"
: "De standaard agenda voor uitnodigingen en nieuwe evenementen"

, "Default Favorite"
: "Standaard favoriet"

, "The default favorite which is loaded on calendar startup"
: "De standaard favoriet die bij het opstarten van agenda wordt geladen"

, "Get Notification Emails"
: "Stuur e-mail melding"

, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
: "Het niveau van de acties die u wilt worden geïnformeerd. Houd er rekening mee dat de organisatoren meldingen krijgt voor alle updates, waaronder genodigde antwoorden, tenzij deze voorkeur is ingesteld op \"Never \""

, "Send Notifications Emails of own Actions"
: "Stuur Email meldingen van eigen acties"

, "Get notifications emails for actions you did yourself"
: "Email meldingen krijgen voor acties die u zelf heeft gedaan"

, "Send Notifications Emails of tentative events"
: ""

, "Get notifications emails of tentative events"
: ""

, "Send Alarm Notifications Emails"
: ""

, "Get event alarms via email"
: ""

, "Enable Standard Alarm"
: "Standaard alarm aan"

, "New events get a standard alarm as defined below"
: "Nieuwe evenementen krijgen een standaard alarm zoals hieronder gedefinieerd"

, "Standard Alarm Time"
: "Standaard Alarm tijd"

, "Minutes before the event starts"
: "Minuten voordat het evenement begint"

, "Default Attendee Strategy"
: ""

, "Default Attendee Strategy for new events"
: ""

, "Time Increment"
: ""

, "Increment of event time steps"
: ""

, "Default set Events to privat"
: ""

, "If enabled every created event is always privat"
: ""

, "First Day of Week"
: ""

, "On what day the week should be starting"
: ""

, "Default calendar strategy"
: ""

, "The calendar for new events if no container is selected"
: ""

, "Fixed Calendars"
: "Vaste kalenders"

, "Calendars always selected regardless of all filter parameters."
: ""

, "Never"
: "Nooit"

, "On invitation and cancellation only"
: "Op uitnodiging en annulering alleen"

, "On time changes"
: "Op tijd veranderingen"

, "On all updates but attendee responses"
: "Op alle updates, maar genodigde reacties"

, "On attendee responses too"
: "Reactie genodigden"

, "Calendars always selected regardless of all filter parameters. A valid use case might be to force the display of an certain holiday calendar."
: "Kalenders altijd geselecteerd ongeacht alle filterparameters. Een geldige use case zou kunnen zijn om de weergave van een bepaalde vakantie kalender dwingen."

, "Crop Days"
: ""

, "Crop calendar view configured start and endtime."
: ""

, "Crop Days Limit Override"
: ""

, "Allow events outside start and endtime."
: ""

, "Week View Mouse Wheel Increment"
: ""

, "Default View for Events"
: ""

, "Event Status Available"
: ""

, "Possible event status. Please note that additional event status might impact other calendar systems on export or synchronisation."
: ""

, "Confirmed"
: ""

, "Canceled"
: ""

, "Event Classes Available"
: ""

, "Possible event classes. Please note that additional event classes might impact other calendar systems on export or synchronisation."
: ""

, "Public"
: ""

, "Confidential"
: ""

, "Event Transparencies Available"
: ""

, "Possible event transparencies. Please note that additional event transparencies might impact other calendar systems on export or synchronisation."
: ""

, "Transparent"
: ""

, "Opaque"
: ""

, "Attendee Status Available"
: "Status van genodigde aanwezig"

, "Possible event attendee status. Please note that additional attendee status might impact other calendar systems on export or synchronisation."
: ""

, "No response"
: "Geen reactie"

, "Accepted"
: "Geaccepteerd"

, "Declined"
: "Afgewezen"

, "Attendee Roles Available"
: ""

, "Possible event attendee roles. Please note that additional attendee roles might impact other calendar systems on export or synchronisation."
: ""

, "Required"
: "Verplicht"

, "Optional"
: "Optioneel"

, "Organizer has implicit edit grant"
: ""

, "Resource Types Available"
: ""

, "Possible resource types. Please note that additional free/busy types might impact other calendar systems on export or synchronisation."
: ""

, "Room"
: ""

, "Board"
: ""

, "Cable"
: ""

, "Car"
: ""

, "Coffee"
: ""

, "Homeoffice"
: ""

, "Lamp"
: ""

, "Laptop"
: ""

, "Material"
: ""

, "Projector"
: ""

, "Travel"
: ""

, "Free/Busy Types Available"
: ""

, "Possible free/busy types. Please note that additional free/busy types might impact other calendar systems on export or synchronisation."
: ""

, "Free"
: ""

, "Busy"
: ""

, "Filter timeslot for CalDAV events"
: ""

, "For how long in the past (in months) the events should be synchronized."
: "Hoever terug in het verleden (in maanden) moeten de evenementen gesynchroniseerd worden."

, "Filter timeslot for CalDAV events with SyncToken"
: ""

, "Timeslot for event notifications"
: ""

, "For how long in the past (in weeks) event notifications should be sent."
: ""

, "Default filter period (from) for events fetched via JSON API"
: ""

, "For how long in the past (in months) the events should be fetched."
: ""

, "Default filter period (until) for events fetched via JSON API"
: ""

, "For how long in the future (in months) the events should be fetched."
: ""

, "Disable iMIP for external organizers"
: ""

, "Disable notification for external organizers"
: ""

, "(CalDAV) Skip double events from personal or shared calendar"
: ""

, "(CalDAV) Skip double events from personal or shared calendar (\"personal\" > Skip events from personal calendar or \"shared\" > Skip events from shared calendar)"
: ""

, "Send notifications to every user with edit permissions of the added resources"
: ""

, "Enabled Features"
: "Ingeschakelde features"

, "Enabled Features in Calendar Application."
: "Ingeschakelde feature in Agenda aplicatie"

, "Calendar Split View"
: "Agenda gesplitst overzicht"

, "Split day and week views by attendee"
: ""

, "Calendar Year View"
: ""

, "Adds year view to Calendar"
: ""

, "Calendar Extended Context Menu Actions"
: ""

, "Adds extended actions to event context menus"
: ""

, "Color Events By"
: ""

, "Choose event color by different criteria"
: ""

, "Recur Events Except"
: ""

, "Recur Events except on certain dates"
: ""

, "Activate Poll for Events"
: ""

, "Create alternative Events and let users as well as externals vote for the best option."
: ""

, "Lead Notification Confirmation"
: ""

, "Send Tentative Notifications"
: ""

, "Send notifications to event organiziers of events that are tentative certain days before event is due"
: ""

, "Enabled"
: ""

, "Days Before Due Date"
: ""

, "How many days before the events due date to start send notifications."
: ""

, "Additional Filter"
: ""

, "Additional filter to limit events notifications should be send for."
: ""

, "Mute Event Notifications for Polls"
: ""

, "Do not send invitations notifications for alternative events in an active poll."
: ""

, "GTCs for polls"
: ""

, "Freebusy Info"
: ""

, "What data the freebusy grant reveals"
: ""

, "only date & time"
: ""

, "and organizer"
: ""

, "and resources"
: ""

, "and calendar"
: ""

, "and other attendees"
: ""

, "Search Attenders Additional Filters"
: ""

, "User Additional Filters"
: ""

, "Group Additional Filters"
: ""

, "Resource Additional Filters"
: ""

, "Assign organizer meeting status on editGrant"
: ""

, "%s's personal calendar"
: "%s's persoonlijke agenda"

, "Failed"
: ""

, "The right Resource Admin must be set once."
: ""

, "Different Calendar"
: ""

, "Exdate container move are not allowed"
: ""

, "Invalid URL given"
: "Ongeldige URL opgegeven"

, "The URL you used is invalid. Please use a valid one!"
: "De URL die u gebruikt is niet geldig. Kies een geldige!"

, "Calendars to export"
: ""

, "Export target"
: ""

, "VCalendar/ICS"
: ""

, "Export visible events to ics file"
: ""

, "Excel overview"
: ""

, "Word event sheet"
: ""

, "Export Events as Calendar Sheet"
: ""

, "VCalendar Report"
: ""

, "Export multiple calendars to ics files"
: ""

, "OpenDocument all data"
: ""

, "Export event data into ods spreadsheet"
: ""

, "Word details"
: ""

, "Excel all data"
: ""

, "Shared Calendar CSV"
: ""

, "Resource CSV"
: ""

, "You can not have more than one grants filter"
: ""

, "Import iCal-files"
: "Importeer iCal-bestanden"

, "unknown"
: "onbekend"

, "This contact has been automatically added by the system as an event attender"
: "Dit contact is automatisch toegevoegd door het systeen als een gebeurtenis genodigde."

, "The email address has been shortened:"
: "Dit email adres is ingekort:"

, "Every %s day"
: "Elke %s dag"

, "Every %s week on"
: "Elke %s week op"

, "Weekly on"
: "Wekelijks op"

, "and"
: "en"

, "Every %1$s month on the %2$s %3$s"
: "Elke %1$s maand op de %2$s %3$s"

, "Monthly every %1$s %2$s"
: "Maandelijks elke %1$s %2$s"

, "Every %1$s month on the %2$s"
: "Elke %1$s maand op de %2$s"

, "Monthly on the %1$s"
: "Maandelijks op de %1$s"

, "Yearly every %1$s %2$s of %3$s"
: "Jaarlijks elke %1$s %2$s van %3$s"

, "Yearly on the %1$s of %2$s"
: "Jaarlijks op de %1$s van %2$s"

, "second to last"
: "tweede tot laatste"

, "fifth"
: "vijfde"

, "st"
: "e"

, "nd"
: "e"

, "rd"
: "e"

, "th"
: "e"

, "Start"
: "Begin"

, "Priority"
: "Prioriteit"

, "Url"
: "Url"

, "Recurrance rule"
: "Herhalings regel"

, "Is all day event"
: "Hele dag afspraak"

, "Organizer timezone"
: "Tijdzone origanisator"

, "Locked"
: ""

, "Closed"
: ""

, "Alarm for event \"%1$s\" at %2$s"
: "Alarm voor evenement \"1$s\" op %2$s"

, "Event invitation \"%1$s\" at %2$s"
: "Uitnodiging evenement \"%1$s\" op %2$s"

, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
: ""

, "Event \"%1$s\" at %2$s has been canceled"
: "Evenement \"%1$s\" op %2$s is afgelast"

, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
: "Evenement \"%1$s\" is verzet naar %2$s tot %3$s"

, "Event \"%1$s\" at %2$s has been updated"
: "Evenement \"%1$s\" op %2$s is aangepast"

, "%1$s accepted event \"%2$s\" at %3$s"
: "%1$s heeft evenement \"%2$s\" op %3$s geaccepteerd "

, "%1$s declined event \"%2$s\" at %3$s"
: "%1$s heeft evenement \"%2$s\" op %3$s afgewezen"

, "Tentative response from %1$s for event \"%2$s\" at %3$s"
: "%1$s is er misschien tijdens evenement \"%2$s\" op %3$s "

, "No response from %1$s for event \"%2$s\" at %3$s"
: "Geen reactie van %1$s voor evenement \"%2$s\" op %3$s"

, "Unknown status update from %1$s for event \"%2$s\" at %3$s"
: ""

, "Attendee changes for event \"%1$s\" at %2$s"
: "Genodigde aanpassingen voor event \"%1$s\" at %2$s"

, "Tentative event notification for event \"%1$s\" at %2$s"
: ""

, "Unknown action"
: ""

, "Resource Management"
: ""

, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
: ""

, "Polls for recurring events are not supported"
: ""

, "This contact has been automatically added by the system as a poll attendee"
: ""

, "Attendance Confirmation for Poll \"%1$s\""
: ""

, "%1$s is scheduled for %2$s"
: ""

, "The poll \"%1$s\" has been closed."
: ""

, "The definite event is scheduled for \"%1$s\""
: ""

, "You can review the poll results here:"
: ""

, "Thank you for attendening the poll \"%1$s\""
: ""

, "To review or edit your status please use your personal link:"
: ""

, "Updates"
: "Updaten"

, "This is an event series exception."
: "Dit is een serie-gebeurtenis uitzondering."

, "%1$s changed from \"%2$s\" to \"%3$s\""
: "%1$s veranderd van \"%2$s\" naar \"%3$s\""

, "%1$s has been invited"
: "%1$s is uitgenodigd"

, "%1$s has been removed"
: "%1$s is verwijderd"

, "%1$s accepted invitation"
: "%1$s uitnodiging geaccepteerd"

, "%1$s declined invitation"
: "%1$s uitnodiging afgewezen"

, "Tentative response from %1$s"
: "%1$s heeft onder voorbehoud gereageerd"

, "No response from %1$s"
: "Geen reactie van %1$s"

, "\"%2$s\" response from %1$s"
: "\"%2$s\" reactie van %1$s"

, "Link"
: ""

, "Event details"
: "Details evenement"

, "All events I attend"
: "Alle evenementen waar ik aanwezig ben"

, "Awaiting response"
: "Wacht op reactie"

, "Events I have not yet responded to"
: "Evenementen waar ik nog niet op gereageerd heb"

, "Declined events"
: "Afgewezen evenementen"

, "Events I have declined"
: "Evenementen die ik heb afgewezen"

, "I'm organizer"
: "Ik ben organisator"

, "Events I'm the organizer of"
: "Evenement waar ik de organisator van ben"

, "manage shared calendars"
: "beheer gedeelde kalenders"

, "Create new shared calendars"
: "Maak nieuwe gedeelde kalenders aan"

, "manage shared calendars favorites"
: "Beheer favorieten gedeele kalenders"

, "Create or update shared calendars favorites"
: "Maak of update favorieten gedeelde kalenders"

, "manage resources"
: "beheer bronnen"

, "All Rights to administrate resources"
: "Alle rechten voor administratieve bronnen"

, "Account"
: ""

, "Exporttime"
: ""

, "First name, ĺast name"
: ""

, "E-Mail address"
: ""

, "Please wait..."
: ""

, "General terms and conditions"
: ""

, "0009326B"
: ""

, "20"
: ""

, "00B359B9"
: ""

, "00997199"
: ""

, "Relation, Relations"
: [
  ""
 ,""


]
, "Poll"
: ""

, "Calendar"
: "Agenda"

, "Do you really want to delete this event?"
: "Weet u zeker dat dit evenement verwijderd moet worden?"

, "Resource Grant"
: ""

, "Event"
: "Evenement"

, "Attender"
: "Genodigde"

, "Resource"
: "Bron"

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
